@@ -18,15 +18,16 @@ get '/ajax/content/report/apclients' => require_login sub {
     my @results = schema('netdisco')->resultset('Device')->search(
         { 'nodes.time_last' => { '>=', \'me.last_macsuck' } },
         {   select => [ 'ip', 'dns', 'name', 'model', 'location' ],
-            join       => { 'ports' => { 'wireless' => 'nodes' } },
+            join       => { 'ports' => { 'ssid' => 'nodes' } },
             '+columns' => [
                 { 'port'        => 'ports.port' },
                 { 'description' => 'ports.name' },
+                { 'ssid'        => 'ssid.ssid' },
                 { 'mac_count'   => { count => 'nodes.mac' } },
             ],
             group_by => [
                 'me.ip',       'me.dns',     'me.name',     'me.model',
-                'me.location', 'ports.port', 'ports.descr', 'ports.name'
+                'me.location', 'ports.port', 'ports.descr', 'ports.name', 'ssid.ssid',
             ],
             order_by => { -desc => [qw/count/] },
         }
@@ -36,12 +37,12 @@ get '/ajax/content/report/apclients' => require_login sub {
 
     if ( request->is_ajax ) {
         my $json = to_json( \@results );
-        template 'ajax/report/portmultinodes.tt', { results => $json },
+        template 'ajax/report/apclients.tt', { results => $json },
             { layout => undef };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
-        template 'ajax/report/portmultinodes_csv.tt',
+        template 'ajax/report/apclients_csv.tt',
             { results => \@results },
             { layout  => undef };
     }
