@@ -19,7 +19,7 @@ register_worker({ phase => 'check' }, sub {
   return Status->defer("macsuck skipped: $device is pseudo-device")
     if $device->is_pseudo;
 
-  return Status->defer("arpnip skipped: $device has no layer 2 capability")
+  return Status->defer("macsuck skipped: $device has no layer 2 capability")
     unless $device->has_layer(2);
 
   return Status->defer("macsuck deferred: $device is not macsuckable")
